@@ -14,16 +14,13 @@
  * limitations under the License.
  */
 
+#include "bson/bson-prelude.h"
+
 
 #ifndef BSON_CONTEXT_H
 #define BSON_CONTEXT_H
 
 
-#if !defined(BSON_INSIDE) && !defined(BSON_COMPILATION)
-#error "Only <bson/bson.h> can be included directly."
-#endif
-
-
 #include "bson/bson-macros.h"
 #include "bson/bson-types.h"
 
